## Notes

### What To Do
- CMD interface calling the tool
- Folder Structure Create
- Base Files Create
- Config Create
- Database Create (psql, mongodb)
- Docker Setup
- Test setup
- Cache Setup
- API Docs Setup